lyricstools.LyricHyphen
=======================

.. inheritance-diagram:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen
   :private-bases:

.. autoclass:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.duration_in_seconds

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.format

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.leaf_index

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.multiplied_duration

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.preprolated_duration

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.duration_multiplier

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.written_duration

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.written_pitch_indication_is_at_sounding_pitch

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.written_pitch_indication_is_nonsemantic

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

Special Methods
---------------

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__and__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__or__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__repr__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__str__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__sub__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricHyphen.LyricHyphen.LyricHyphen.__xor__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`
